/**********************************************************************
* File: Gpio.c
* Devices: TMS320F2837xD
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "Lab.h"						// Main include file


/**********************************************************************
* Function: InitGpio()
*
* Description: Initializes the shared GPIO pins on the F2837xD
**********************************************************************/
void InitGpio(void)
{
//--- Unlock the configuration registers for pins on all ports
	Device_initGPIO();                              // (FILE: device.c)

//--- Configure EPWM1A on GPIO0 (used in Lab 7)
    GPIO_setPadConfig(0, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO0
    GPIO_setPinConfig(GPIO_0_EPWM1A);               // GPIO0 = EPWM1A
	
//--- Configure GPIO24 as input for ECAP1 via INPUT X-BAR (used in Lab 7)
    GPIO_setPadConfig(24, GPIO_PIN_TYPE_PULLUP);    // Enable pull-up on GPIO24
    GPIO_setPinConfig(GPIO_24_GPIO24);              // GPIO24 = GPIO24	
    GPIO_setQualificationMode(24, GPIO_QUAL_SYNC);  // Synch to SYSCLKOUT
    GPIO_setDirectionMode(24, GPIO_DIR_MODE_IN);    // GPIO24 = input
    XBAR_setInputPin(XBAR_INPUT7, 24);              // GPIO24 = ECAP1	

//--- Configure GPIO34 as output (connected to LED)
    GPIO_setPadConfig(34, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO34
    GPIO_setPinConfig(GPIO_34_GPIO34);               // GPIO34 = GPIO34
    GPIO_setDirectionMode(34, GPIO_DIR_MODE_OUT);    // GPIO34 = output
    GPIO_writePin(34, 1);                            // Load output latch
	
//--- Configure GPIO19 as output (used in Lab 6 - pin high)
    GPIO_setPadConfig(19, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO19
    GPIO_setPinConfig(GPIO_19_GPIO19);               // GPIO19 = GPIO19
    GPIO_setDirectionMode(19, GPIO_DIR_MODE_OUT);    // GPIO19 = output
    GPIO_writePin(19, 1);                            // Load output latch

//--- Configure GPIO18 as output (used in Lab 6 - pin toggle)
    GPIO_setPadConfig(18, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO18
    GPIO_setPinConfig(GPIO_18_GPIO18);               // GPIO18 = GPIO18
    GPIO_setDirectionMode(18, GPIO_DIR_MODE_OUT);    // GPIO18 = output
	
//--- Configure GPIO31 as output (used in Lab 11 - connected to LED)
    GPIO_setMasterCore(31, GPIO_CORE_CPU2);          // GPIO31 is controlled by CPU2
    GPIO_setPadConfig(31, GPIO_PIN_TYPE_PULLUP);     // Enable pull-up on GPIO31
    GPIO_setPinConfig(GPIO_31_GPIO31);               // GPIO31 = GPIO31
    GPIO_setDirectionMode(31, GPIO_DIR_MODE_OUT);    // GPIO31 = output
    GPIO_writePin(31, 1);                            // Load output latch

//--- Lock the configuration registers for pins on all ports
    GPIO_lockPortConfig(GPIO_PORT_A, 0xFFFFFFFF);
    GPIO_lockPortConfig(GPIO_PORT_B, 0xFFFFFFFF);
    GPIO_lockPortConfig(GPIO_PORT_C, 0xFFFFFFFF);
    GPIO_lockPortConfig(GPIO_PORT_D, 0xFFFFFFFF);
    GPIO_lockPortConfig(GPIO_PORT_E, 0xFFFFFFFF);
    GPIO_lockPortConfig(GPIO_PORT_F, 0xFFFFFFFF);

} // end InitGpio()


//--- end of file -----------------------------------------------------
