/**********************************************************************
* File: DefaultIsr_11_cpu1.c
* Devices: TMS320F2837xD
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "F2837xD_device.h"             // F2837xD header file peripheral address definitions
#include "Lab.h"						// Main include file


//---------------------------------------------------------------------
interrupt void adcA1ISR(void)                           // PIE1.1 @ 0x000D40  ADC-A interrupt #1
{
static volatile uint16_t GPIO34_count = 0;              // Counter for pin toggle

	Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP1);      // Must acknowledge the PIE group

//--- Manage the ADC interrupt flag
	ADC_clearInterruptStatus(ADCA_BASE, ADC_INT_NUMBER1);	// Clear ADCINT1 flag

//--- Read the ADC result
	AdcResult = ADC_readResult(ADCARESULT_BASE, ADC_SOC_NUMBER0);    // Read the result
	IpcRegs.IPCSENDDATA = (uint32_t) AdcResult;     // Write the result to the IPC data register
	IpcRegs.IPCSET.bit.IPC1 = 1;                    // Set the IPC1 flag for CPU2
	
//--- Example: Toggle GPIO34 at a 0.5 sec rate (connected to the LED).
//             (1/50000 sec/sample)*(1 samples/int)*(x interrupts/toggle) = (0.5 sec/toggle)
//             ==> x = 25000
	if(GPIO34_count++ > 25000)					    // Toggle slowly to see the LED blink
	{
	    GPIO_togglePin(34);	                        // Toggle the pin
		GPIO34_count = 0;						    // Reset the counter
	}
}

//---------------------------------------------------------------------
interrupt void wakeISR(void)                            // PIE1.8 @ 0x000D4E  WAKE interrupt (LPM/WD)
{
	Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP1);      // Must acknowledge the PIE group
  
// Next two lines for debug only - remove after inserting your ISR
	asm (" ESTOP0");                                    // Emulator Halt instruction
	while(1);
}

//---------------------------------------------------------------------
interrupt void ipc0ISR(void)						// PIE1.13 @ 0x000E08  Inter-processor communication interrupt #0
{
	Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP1);      // Must acknowledge the PIE group

//--- Manage the IPC registers
	IpcRegs.IPCACK.bit.IPC0 = 1;                    // Clear IPC0 flag

//--- Read IPC channel 0 and write to DAC-B
	DacData = (uint16_t) IpcRegs.IPCRECVADDR;       // Read data on IPC ADDR register
	DAC_setShadowValue(DACB_BASE, DacData);         // Write to DAC-B
}


//--- end of file -----------------------------------------------------
