/**********************************************************************
* File: Main_11_cpu1.c
* Devices: TMS320F28379D
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "F2837xD_device.h"             // F2837xD header file peripheral address definitions
#include "Lab.h"                        // Main include file

//--- Global Variables
uint16_t DacData;                       // DAC value from CPU2 via IPC0
uint16_t AdcResult;                     // ADC result to CPU2 via IPC1


/**********************************************************************
* Function: main()
*
* Description: Main function for C28x workshop labs
**********************************************************************/
void main(void)
{
//--- CPU Initialization
    Device_init();                      // Initialize device and peripherals clock (FILE: device.c)
	Interrupt_initModule();             // Initializes PIE, clear PIE registers, disables CPU interrupts, and clear all CPU interrupt flags (FILE: interrupt.c)
	Interrupt_initVectorTable();        // Initialize the PIE vector table with pointers to the shell interrupt Service Routines (FILE: interrupt.c)
    InitGpio();                         // Initialize the shared GPIO pins (FILE: Gpio.c)
	InitWatchdog();						// Initialize the Watchdog Timer (FILE: WatchDog.c)

//--- Peripheral Initialization
	InitAdca();							// Initialize the ADC-A (FILE: Adc.c)
	InitDacb();                         // Initialize the DAC-B (File: Dac.c)
	InitEPwm();							// Initialize the EPwm (FILE: EPwm.c) 

//--- Clear IPC Flags
	IpcRegs.IPCCLR.all = 0xFFFFFFFF;

//--- Enable IPC0 PIE interrupt
	Interrupt_register(INT_IPC_0, &ipc0ISR);     // Re-map IPC0 interrupt signal to call the ISR function
    Interrupt_enable(INT_IPC_0);                 // Enable IPC0 in PIE group 1 and enable INT1 in IER to enable PIE group 1

//--- Wait here until CPU2 is ready
	while (IpcRegs.IPCSTS.bit.IPC17 == 0) ;	// Wait for CPU2 to set IPC17
	IpcRegs.IPCACK.bit.IPC17 = 1;			// Acknowledge and clear IPC17

//--- Enable global interrupts and real-time debug
	EINT;                               // Enable global interrupts - defined as: asm(" clrc INTM"); (FILE: cpu.h)
	ERTM;                               // Enable real-time debug - defined as: asm(" clrc DBGM"); (FILE: cpu.h)

//--- Main Loop
	while(1)							// endless loop - wait for an interrupt
	{
		NOP;                            // No operation - defined as: asm(" NOP"); (FILE: cpu.h)
	}

} //end of main()


/*** end of file *****************************************************/
