/**********************************************************************
* File: DefaultIsr_11_cpu1.c
* Devices: TMS320F2837xD
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "F2837xD_device.h"             // F2837xD header file peripheral address definitions
#include "Lab.h"						// Main include file


//---------------------------------------------------------------------
interrupt void wakeISR(void)                            // PIE1.8 @ 0x000D4E  WAKE interrupt (LPM/WD)
{
	Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP1);      // Must acknowledge the PIE group
  
// Next two lines for debug only - remove after inserting your ISR
	asm (" ESTOP0");                                    // Emulator Halt instruction
	while(1);
}

//---------------------------------------------------------------------
interrupt void ipc1ISR(void)						// PIE1.14 @ 0x000E0A Inter-processor communication interrupt #1
{
static uint16_t *AdcBufPtr = AdcBuf;				// Pointer to buffer
static uint16_t iQuadratureTable = 0;				// Quadrature table index
static volatile uint16_t GPIO31_count = 0;			// Counter for pin toggle

	Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP1);      // Must acknowledge the PIE group

//--- Manage the IPC registers
	IpcRegs.IPCACK.bit.IPC1 = 1;                    // Clear IPC1 flag

//--- Read the ADC result from IPC1
	*AdcBufPtr++ = (uint16_t) IpcRegs.IPCRECVDATA;  // Read the result

//--- Brute-force the circular buffer
	if( AdcBufPtr == (AdcBuf + ADC_BUF_LEN) )
	{	
		AdcBufPtr = AdcBuf;                         // Rewind the pointer to beginning
	}

//--- Write next data point from sine table
	SineData = ((QuadratureTable[iQuadratureTable++] ^ 0x8000) >> 5);
    if(iQuadratureTable > (SINE_PTS - 1))           // Wrap the index
    {
        iQuadratureTable = 0;
    }
	IpcRegs.IPCSENDADDR = (uint16_t) SineData;
	IpcRegs.IPCSET.bit.IPC0 = 1;                    // Set IPC0 bit for CPU1

//--- Example: Toggle GPIO31 at a 0.1 sec rate (connected to the LED).
//             (1/50000 sec/sample)*(1 samples/int)*(x interrupts/toggle) = (0.1 sec/toggle)
//             ==> x = 5000
	if(GPIO31_count++ > 5000)                      // Toggle slowly to see the LED blink
	{
	    GPIO_togglePin(31);	                        // Toggle the pin
		GPIO31_count = 0;						    // Reset the counter
	}
}


//--- end of file -----------------------------------------------------
