/**********************************************************************
* File: Main_11_cpu2.c
* Devices: TMS320F28379D
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "F2837xD_device.h"             // F2837xD header file peripheral address definitions
#include "Lab.h"                        // Main include file

//--- Global Variables
uint16_t AdcBuf[ADC_BUF_LEN];           // ADC buffer allocation
uint16_t SineData;                      // Sine table data to CPU1 via IPC0


/**********************************************************************
* Function: main()
*
* Description: Main function for C28x workshop labs
**********************************************************************/
void main(void)
{
//--- CPU Initialization
	Interrupt_initModule();             // Initializes PIE, clear PIE registers, disables CPU interrupts, and clear all CPU interrupt flags (FILE: interrupt.c)
	Interrupt_initVectorTable();        // Initialize the PIE vector table with pointers to the shell interrupt Service Routines (FILE: interrupt.c)
	InitWatchdog();						// Initialize the Watchdog Timer (FILE: WatchDog.c)

//--- Enable global interrupts
	asm(" CLRC INTM, DBGM");			// Enable global interrupts and realtime debug

//--- Clear IPC1 Flag
    IpcRegs.IPCCLR.bit.IPC1 = 1;
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP1);

//--- Enable IPC1 PIE interrupt
	Interrupt_register(INT_IPC_1, &ipc1ISR);     // Re-map IPC1 interrupt signal to call the ISR function
    Interrupt_enable(INT_IPC_1);                 // Enable IPC1 in PIE group 1 and enable INT1 in IER to enable PIE group 1

//--- Let CPU1 know that CPU2 is ready
	IpcRegs.IPCSET.bit.IPC17 = 1;		// Set IPC17 to release CPU1

//--- Enable global interrupts and real-time debug
	EINT;                               // Enable global interrupts - defined as: asm(" clrc INTM"); (FILE: cpu.h)
	ERTM;                               // Enable real-time debug - defined as: asm(" clrc DBGM"); (FILE: cpu.h)
	
//--- Main Loop
	while(1)							// endless loop - wait for an interrupt
	{
		NOP;                            // No operation - defined as: asm(" NOP"); (FILE: cpu.h)
	}

} //end of main()


/*** end of file *****************************************************/
