/**********************************************************************
* File: Dma.c
* Devices: TMS320F2837xD
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "Lab.h"						// Main include file


/**********************************************************************
* Function: InitDma()
*
* Description: Initializes the DMA on the F2837xD
**********************************************************************/
void InitDma(void)
{
//---------------------------------------------------------------------
//--- Initializes the DMA controller to a known state:
//    This function performs a hard reset of the DMA controller and
//    also sets the DMA to run free during an emulation suspend.
//---------------------------------------------------------------------
	DMA_initController();

//---------------------------------------------------------------------
//--- Configure DMA channel 1 to read the ADC results         
//---------------------------------------------------------------------

//--- ADCAINT1 triggers start of a DMA CH1 transfer; 1 burst transfer per event trigger; DMA reinitializes after transfer complete; 16-bit data size
	DMA_configMode(DMA_CH1_BASE, DMA_TRIGGER_ADCA1, DMA_CFG_ONESHOT_DISABLE | DMA_CFG_CONTINUOUS_ENABLE | DMA_CFG_SIZE_16BIT);
    DMA_enableTrigger(DMA_CH1_BASE);                                // Enable peripheral interrupt trigger for DMA transfer
	DMA_setInterruptMode(DMA_CH1_BASE, DMA_INT_AT_BEGINNING);       // Generate interrupt at the beginning of a new transfer
	DMA_enableInterrupt(DMA_CH1_BASE);                              // Enable DMA channel CPU interrupt

	DMA_configAddresses(DMA_CH1_BASE, (const void *)AdcBufRaw, (const void *)(ADCARESULT_BASE + ADC_O_RESULT0));    // destination address, source address
	DMA_configBurst(DMA_CH1_BASE, 1, 0, 0);                         // 1 word/burst, source burst step = 0, destination burst step = 0
	DMA_configTransfer(DMA_CH1_BASE, ADC_BUF_LEN, 0, 1);            // 50 bursts/transfer, source transfer step = 0, destination transfer step = 1

//--- Enable the DMA interrupt
    Interrupt_register(INT_DMA_CH1, &dmaCh1ISR);    // Re-map DINTCH1 interrupt signal to call the ISR function
    Interrupt_enable(INT_DMA_CH1);                  // Enable DINTCH1 in PIE group 7 and enable INT7 in IER to enable PIE group 7

//--- Finish up
    DMA_startChannel(DMA_CH1_BASE);     // Start DMA channel (run - wait for the first trigger event to start operation)

} // end InitDma()


//*** end of file *****************************************************
